@@ -25,6 +25,8 @@
 #include <capnp/dynamic.h>
 #include <capnp/compat/json.capnp.h>
 
+CAPNP_BEGIN_HEADER
+
 namespace capnp {
 
 typedef json::Value JsonValue;
@@ -60,9 +62,7 @@ class JsonCodec {
   //   different ways people do this.
   // - Encoding/decoding capabilities and AnyPointers requires registering a Handler, since there's
   //   no obvious default behavior.
-  // - When decoding, unrecognized field names are ignored. Note: This means that JSON is NOT a
-  //   good format for receiving input from a human. Consider `capnp eval` or the SchemaParser
-  //   library for human input.
+  // - When decoding, fields with unknown names are ignored by default to allow schema evolution.
 
 public:
   JsonCodec();
@@ -85,6 +85,11 @@ public:
   // setHasMode(HasMode::NON_DEFAULT) to specify that default-valued primitive fields should be
   // omitted as well.
 
+  void setRejectUnknownFields(bool enable);
+  // Choose whether decoding JSON with unknown fields should produce an error. You may trade
+  // allowing schema evolution against a guarantee that all data is preserved when decoding JSON
+  // by toggling this option. The default is to ignore unknown fields.
+
   template <typename T>
   kj::String encode(T&& value) const;
   // Encode any Cap'n Proto value to JSON, including primitives and
@@ -520,3 +525,5 @@ void JsonCodec::handleByAnnotation() {
 }
 
 } // namespace capnp
+
+CAPNP_END_HEADER
